@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Base;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Base module for importing standard modules, features, and subs
 
 #pod =head1 SYNOPSIS
@@ -39,10 +39,16 @@ use base 'Import::Base';
 our @IMPORT_MODULES = (
     'strict', 'warnings',
     feature => [qw( :5.24 signatures )],
-    '-warnings' => [qw( experimental::signatures )],
+    '>-warnings' => [qw( experimental::signatures )],
 );
 
 our %IMPORT_BUNDLES = (
+    Result => [
+        'DBIx::Class::Candy',
+    ],
+    ResultSet => [
+        'DBIx::Class::Candy::ResultSet',
+    ],
     Test => [
         'Test::More', 'Test::Lib',
         'Local::Schema' => [qw( prepare_temp_schema )],
@@ -61,7 +67,7 @@ CPAN::Testers::Schema::Base - Base module for importing standard modules, featur
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
