@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Result::LatestIndex;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: A cache of the latest version of a dist by author
 
 #pod =head1 SYNOPSIS
@@ -54,10 +54,9 @@ our $VERSION = '0.002';
 #pod
 #pod =cut
 
-use CPAN::Testers::Schema::Base;
-use base 'DBIx::Class::Core';
+use CPAN::Testers::Schema::Base 'Result';
 
-__PACKAGE__->table( 'ixlatest' );
+table 'ixlatest';
 
 #pod =attr dist
 #pod
@@ -66,12 +65,10 @@ __PACKAGE__->table( 'ixlatest' );
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    dist => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    },
-);
+column dist => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr author
 #pod
@@ -80,14 +77,12 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    author => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column author => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
-__PACKAGE__->set_primary_key( qw( dist author ) );
+primary_key qw( dist author );
 
 #pod =attr version
 #pod
@@ -96,12 +91,10 @@ __PACKAGE__->set_primary_key( qw( dist author ) );
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    version => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column version => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr released
 #pod
@@ -110,12 +103,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    released => {
-        data_type => 'bigint',
-        is_nullable => 0,
-    }
-);
+column released => {
+    data_type => 'bigint',
+    is_nullable => 0,
+};
 
 #pod =attr oncpan
 #pod
@@ -127,12 +118,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    oncpan => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column oncpan => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr uploadid
 #pod
@@ -140,12 +129,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    uploadid => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column uploadid => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =method upload
 #pod
@@ -154,9 +141,7 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->belongs_to(
-    upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid',
-);
+belongs_to upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid';
 
 1;
 
@@ -170,7 +155,7 @@ CPAN::Testers::Schema::Result::LatestIndex - A cache of the latest version of a
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
