@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Result::Release;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Collected test report stats about a single CPAN release
 
 #pod =head1 SYNOPSIS
@@ -43,10 +43,8 @@ our $VERSION = '0.002';
 #pod
 #pod =cut
 
-use CPAN::Testers::Schema::Base;
-use base 'DBIx::Class::Core';
-
-__PACKAGE__->table( 'release_summary' );
+use CPAN::Testers::Schema::Base 'Result';
+table 'release_summary';
 
 #pod =attr dist
 #pod
@@ -54,12 +52,10 @@ __PACKAGE__->table( 'release_summary' );
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    dist => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column dist => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr version
 #pod
@@ -67,12 +63,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    version => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column version => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr id
 #pod
@@ -81,12 +75,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    id => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column id => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr guid
 #pod
@@ -95,12 +87,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    guid => {
-        data_type => 'char',
-        is_nullable => 0,
-    }
-);
+column guid => {
+    data_type => 'char',
+    is_nullable => 0,
+};
 
 #pod =attr oncpan
 #pod
@@ -109,12 +99,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    oncpan => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column oncpan => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr distmat
 #pod
@@ -124,12 +112,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    distmat => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column distmat => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr perlmat
 #pod
@@ -138,12 +124,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    perlmat => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column perlmat => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr patched
 #pod
@@ -152,12 +136,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    patched => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column patched => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr pass
 #pod
@@ -165,12 +147,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    pass => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column pass => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr fail
 #pod
@@ -178,12 +158,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    fail => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column fail => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr na
 #pod
@@ -191,12 +169,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    na => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column na => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr unknown
 #pod
@@ -204,12 +180,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    unknown => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column unknown => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr uploadid
 #pod
@@ -217,12 +191,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    uploadid => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column uploadid => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =method upload
 #pod
@@ -231,9 +203,7 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->belongs_to(
-    upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid',
-);
+belongs_to upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid';
 
 #pod =method report
 #pod
@@ -246,10 +216,9 @@ __PACKAGE__->belongs_to(
 #pod
 #pod =cut
 
-__PACKAGE__->belongs_to(
-    report => 'CPAN::Testers::Schema::Result::Stats',
-    { 'foreign.guid' => 'self.guid' },
-);
+belongs_to report => 'CPAN::Testers::Schema::Result::Stats', {
+    'foreign.guid' => 'self.guid',
+};
 
 1;
 
@@ -263,7 +232,7 @@ CPAN::Testers::Schema::Result::Release - Collected test report stats about a sin
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
