@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Result::ReleaseStat;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: A single test report reduced to a simple pass/fail
 
 #pod =head1 SYNOPSIS
@@ -48,10 +48,8 @@ our $VERSION = '0.002';
 #pod
 #pod =cut
 
-use CPAN::Testers::Schema::Base;
-use base 'DBIx::Class::Core';
-
-__PACKAGE__->table( 'release_data' );
+use CPAN::Testers::Schema::Base 'Result';
+table 'release_data';
 
 #pod =attr dist
 #pod
@@ -59,12 +57,10 @@ __PACKAGE__->table( 'release_data' );
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    dist => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column dist => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr version
 #pod
@@ -72,12 +68,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    version => {
-        data_type => 'varchar',
-        is_nullable => 0,
-    }
-);
+column version => {
+    data_type => 'varchar',
+    is_nullable => 0,
+};
 
 #pod =attr id
 #pod
@@ -86,12 +80,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    id => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column id => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr guid
 #pod
@@ -100,12 +92,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    guid => {
-        data_type => 'char',
-        is_nullable => 0,
-    }
-);
+column guid => {
+    data_type => 'char',
+    is_nullable => 0,
+};
 
 __PACKAGE__->set_primary_key(qw( id guid ));
 
@@ -116,12 +106,10 @@ __PACKAGE__->set_primary_key(qw( id guid ));
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    oncpan => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column oncpan => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr distmat
 #pod
@@ -131,12 +119,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    distmat => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column distmat => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr perlmat
 #pod
@@ -145,12 +131,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    perlmat => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column perlmat => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr patched
 #pod
@@ -159,12 +143,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    patched => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column patched => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr pass
 #pod
@@ -172,12 +154,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    pass => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column pass => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr fail
 #pod
@@ -185,12 +165,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    fail => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column fail => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr na
 #pod
@@ -198,12 +176,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    na => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column na => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr unknown
 #pod
@@ -211,12 +187,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    unknown => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column unknown => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =attr uploadid
 #pod
@@ -224,12 +198,10 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->add_column(
-    uploadid => {
-        data_type => 'int',
-        is_nullable => 0,
-    }
-);
+column uploadid => {
+    data_type => 'int',
+    is_nullable => 0,
+};
 
 #pod =method upload
 #pod
@@ -238,9 +210,7 @@ __PACKAGE__->add_column(
 #pod
 #pod =cut
 
-__PACKAGE__->belongs_to(
-    upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid',
-);
+belongs_to upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid';
 
 1;
 
@@ -254,7 +224,7 @@ CPAN::Testers::Schema::Result::ReleaseStat - A single test report reduced to a s
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
