@@ -9,12 +9,13 @@ package Local::Schema;
 
 =head1 DESCRIPTION
 
+This module creates a local temporary database for testing the schema
+and ORM.
+
 =head1 SEE ALSO
 
 =over
 
-=item L<File::Temp>
-
 =item L<DBD::SQLite>
 
 =back
@@ -23,7 +24,6 @@ package Local::Schema;
 
 use CPAN::Testers::Schema::Base;
 use CPAN::Testers::Schema;
-use File::Temp;
 use Exporter qw( import );
 our @EXPORT_OK = qw(
     prepare_temp_schema
